file.choose ()

## Table 3 Comparison of overall genetic diversity statistics between native and introduced populations of Heracleum persicum.
basic_stat_25_loci<-read.csv (file.choose(), header=T)
attach (basic_stat_25_loci)
names (basic_stat_25_loci)

t.test (N_25 [1:6], N_25 [7:38])
t.test (Na_25 [1:6], Na_25 [7:38])
t.test (Ne_25 [1:6], Ne_25 [7:38])
t.test (I_25 [1:6], I_25 [7:38])
t.test (Ho_25 [1:6], Ho_25 [7:38])
t.test (He_25 [1:6], He_25 [7:38])
t.test (uHe_25 [1:6], uHe_25 [7:38])
t.test (F_25 [1:6], F_25 [7:38])
t.test (X.P_25 [1:6]*100, X.P_25 [7:38]*100)
t.test (Pa_25 [1:6], Pa_25 [7:38])
t.test (AR_20 [1:6], AR_20 [7:38])
t.test (Null_25 [1:6], Null_25 [7:38])

## comparison of global FST with and without null alleles
gFST_with_without_null<-read.csv (file.choose(), header=T)
attach (gFST_with_without_null)
names (gFST_with_without_null)

# comparison of FST with and without null alleles
t.test (FST_no_ENA, FST_with_ENA)                                               # ns
# Comparison of FST between native and introduced range without correction for null alleles
t.test (FST_no_ENA [1:6], FST_no_ENA [7:38])                                    # ns
# Comparison of FST between native and introduced range with correction for null alleles
t.test (FST_with_ENA [1:6], FST_with_ENA [7:38])                                # ns

## Genetic differentiation (FST) between native and introduced populations

FST_nat_intro<- read.csv (file.choose(), header=T)
attach (FST_nat_intro)
names (FST_nat_intro)
t.test (FST [1:15], FST [16:291])


## Fig. S1 Relationship between number of alleles per locus and null allele frequency in Heracleum persicum. 
## Horizontal broken line is set at 0.05 null allele frequency.
## Null alllele Vs. number of allele
null_allele_no_allele<-read.csv (file.choose (),header=T)
attach (null_allele_no_allele)
names (null_allele_no_allele)

## Correlation between null alleles and null alleles
cor.test (Null_allele, No_alleles)
## fitting linear model
fit_null.lm<-lm(Null_allele ~ No_alleles)
summary (fit_null.lm)

## making pdf file of the plot
pdf("Fig S1 Number of alleles and null alleles.pdf", width = 6.65, height = 7)

par(mfrow = c(1, 1), mar = c(3.2, 3.2, 0.2, 0.3), oma = c(5, 0, 0, 0), tcl = -0.25, mgp = c(2, 0.6, 0))

plot (Null_allele ~ No_alleles, xlab="# Alleles/locus", ylab="Null allele frequency", pch=16, col='blue', cex=1.5)

abline (fit_null.lm, col='blue')
abline (h=0.05, lty=2, col='red', lwd=2)  ### straight line ## h = y-value for horizontal line and ## v=x-value for vertical line
legend.text = c (expression (r^2~"= 0.49"), "p = 0.000")
legend ("topleft", legend=legend.text, bty='n')

dev.off ()

## Fig. 5 Log scaled marginal densities of migration rate of Heracleum persicum 
## from Norway to Finland (dashed line) and Finland to Norway (solid line) estimated by IM analysis.

ima_dat<-read.csv (file.choose (), header=T)
attach (ima_dat)
names (ima_dat)

## plotting correctly sized pdf file

pdf("Fig. 6 Isolation with migration.pdf", width = 4.72, height = 4)

par(mar=c(3,3,0,0), mai=c(0.54,0.54,0.08,0.08), mgp=c(1.5,0.5,0))

plot (log(m1+1),log (m2_L+1), type='n', xlim=c(0, 5.53), ylim=c(0,0.045), xlab='Marginal density for migration rate', ylab='Posterior probability')
lines (log (m1+1), log (m1_L+1), col='red', lty=1, lwd=4)
lines (log (m2+1), log (m2_L+1), col='blue', lty=6, lwd=4)

legend ("topleft", c('Norway', 'Finland'), lty=c(1,6), col=c('red','blue'), lwd=c(4,4), bty='n')

dev.off ()